@@ -4,7 +4,7 @@ knitr::opts_chunk$set(collapse = T, comment = "#>",
 
 required <- c("dplyr")
 
-if (!all(unlist(lapply(required, function(pkg) requireNamespace(pkg, quietly = TRUE)))))
+if (!all(sapply(required, requireNamespace, quietly = TRUE)))
   knitr::opts_chunk$set(eval = FALSE)
 
 ## ------------------------------------------------------------------------
