@@ -5,11 +5,49 @@
 #include "simulator.h"
 #include "policy.h"
 
-#define LABEL(name) (#name": ") << name
-#define LABELC(name) LABEL(name) << ", "
-#define LABELE(name) LABEL(name) << " }" << std::endl
-#define C(name) name << ", "
-#define E(name) name << std::endl;
+#define SEP ", "
+#define ENDL std::endl
+#define BENDL " }" << ENDL
+
+#define LABEL1(a) (#a": ") << a
+#define LABEL2(a, b) LABEL1(a) << SEP << LABEL1(b)
+#define LABEL3(a, b, c) LABEL1(a) << SEP << LABEL2(b, c)
+#define LABEL4(a, b, c, d) LABEL1(a) << SEP << LABEL3(b, c, d)
+
+#define BARE1(a) a
+#define BARE2(a, b) BARE1(a) << SEP << BARE1(b)
+#define BARE3(a, b, c) BARE1(a) << SEP << BARE2(b, c)
+#define BARE4(a, b, c, d) BARE1(a) << SEP << BARE3(b, c, d)
+
+
+template <typename T, typename U, typename V>
+class FnWrap {
+public:
+  FnWrap() {}
+  FnWrap(const Fn<T(U)>& call, const V& arg) : call(call), arg(arg) {}
+
+  T operator()(U param) { return call(param); }
+
+  friend std::ostream& operator<<(std::ostream& out, const FnWrap<T, U, V>& fn) {
+    out << fn.arg;
+    return out;
+  }
+
+private:
+  Fn<T(U)> call;
+  V arg;
+};
+
+template <typename T>
+Fn<T(T, T)> get_op(char mod) {
+  switch(mod) {
+  case '+':
+    return BIND(std::plus<double>(), _1, _2);
+  case '*':
+    return BIND(std::multiplies<double>(), _1, _2);
+  }
+  return NULL;
+}
 
 /**
  *  Base class.
@@ -19,7 +57,6 @@ public:
   BASE_CLONEABLE(Activity)
 
   std::string name;
-  VEC<int> provide_attrs;
   int count;
   int priority;
 
@@ -27,16 +64,13 @@ public:
    * Constructor.
    * @param name          the name of the activity
    * @param resource      the resource associated
-   * @param provide_attrs whether the activity should expose the arrival's attributes
    * @param priority      simulation priority
    */
-  Activity(const std::string& name, const VEC<int>& provide_attrs = VEC<int>(0), int priority = 0)
-    : name(name), provide_attrs(provide_attrs), count(1),
-      priority(priority), next(NULL), prev(NULL) {}
+  Activity(const std::string& name, int priority = 0)
+    : name(name), count(1), priority(priority), next(NULL), prev(NULL) {}
 
   Activity(const Activity& o)
-    : name(o.name), provide_attrs(o.provide_attrs), count(o.count),
-      priority(o.priority), next(NULL), prev(NULL) {}
+    : name(o.name), count(o.count), priority(o.priority), next(NULL), prev(NULL) {}
 
   virtual ~Activity() {}
 
@@ -80,35 +114,28 @@ protected:
   Activity* prev;
 
   template <typename T>
-  T get(const T& var, int index, Arrival* arrival) const { return var; }
+  T get(const T& var, Arrival* arrival) const { return var; }
 
   template <typename T>
-  T get(const Rcpp::Function& call, int index, Arrival* arrival) const {
-    switch (provide_attrs[index]) {
-    case 1: // # nocov start
-      return Rcpp::as<T>(call(*arrival->get_attributes()));
-    case 2:
-      return Rcpp::as<T>(call(*arrival->get_attributes(),
-                              *arrival->sim->get_attributes())); // # nocov end
-    default:
-      return Rcpp::as<T>(call());
-    }
-  }
+  T get(const RFn& call, Arrival* arrival) const { return Rcpp::as<T>(call()); }
+
+  template <typename T>
+  T get(const Fn<T(Arrival*)>& call, Arrival* arrival) const { return call(arrival); }
 };
 
 // abstract class for multipath activities
 class Fork : public Activity {
 public:
-  Fork(const std::string& name, const VEC<bool>& cont, const VEC<Rcpp::Environment>& trj,
-       const VEC<int>& provide_attrs = VEC<int>(0), int priority = 0)
-    : Activity(name, provide_attrs, priority), cont(cont), trj(trj), selected(NULL)
+  Fork(const std::string& name, const VEC<bool>& cont,
+       const VEC<REnv>& trj, int priority = 0)
+    : Activity(name, priority), cont(cont), trj(trj), selected(NULL)
   {
-    foreach_ (const VEC<Rcpp::Environment>::value_type& itr, trj) {
-      Rcpp::Function head(itr["head"]);
-      Rcpp::Function tail(itr["tail"]);
+    foreach_ (const VEC<REnv>::value_type& itr, trj) {
+      RFn head(itr["head"]);
+      RFn tail(itr["tail"]);
       heads.push_back(Rcpp::as<Rcpp::XPtr<Activity> >(head()));
       tails.push_back(Rcpp::as<Rcpp::XPtr<Activity> >(tail()));
-      Rcpp::Function get_n_activities(itr["get_n_activities"]);
+      RFn get_n_activities(itr["get_n_activities"]);
       count += Rcpp::as<int>(get_n_activities());
     }
     foreach_ (const VEC<Activity*>::value_type& itr, heads)
@@ -118,11 +145,11 @@ public:
   Fork(const Fork& o) : Activity(o), cont(o.cont), trj(o.trj), selected(NULL) {
     heads.clear();
     tails.clear();
-    foreach_ (VEC<Rcpp::Environment>::value_type& itr, trj) {
-      Rcpp::Function clone(itr["clone"]);
+    foreach_ (VEC<REnv>::value_type& itr, trj) {
+      RFn clone(itr["clone"]);
       itr = clone();
-      Rcpp::Function head(itr["head"]);
-      Rcpp::Function tail(itr["tail"]);
+      RFn head(itr["head"]);
+      RFn tail(itr["tail"]);
       heads.push_back(Rcpp::as<Rcpp::XPtr<Activity> >(head()));
       tails.push_back(Rcpp::as<Rcpp::XPtr<Activity> >(tail()));
     }
@@ -137,7 +164,7 @@ public:
       for (unsigned int i = 0; i < trj.size(); i++) {
         Rcpp::Rcout <<
           IND(indent) << "Fork " << i+1 << (cont[i] ? ", continue," : ", stop,");
-        Rcpp::Function print(trj[i]["print"]);
+        RFn print(trj[i]["print"]);
         print(indent, verbose);
       }
     } else Rcpp::Rcout << trj.size() << " paths" << std::endl;
@@ -161,7 +188,7 @@ public:
 
 protected:
   VEC<bool> cont;
-  VEC<Rcpp::Environment> trj;
+  VEC<REnv> trj;
   Activity* selected;
   VEC<Activity*> heads;
   VEC<Activity*> tails;
@@ -172,11 +199,10 @@ class ResGetter {
 public:
   BASE_CLONEABLE(ResGetter)
 
-  ResGetter(const std::string& name, const std::string& resource, int id = -1)
-    : name(name), resource(resource), id(id) {}
+  ResGetter(const std::string& activity, const std::string& resource, int id = -1)
+    : resource(resource), id(id), activity(activity) {}
 
 protected:
-  std::string name;
   std::string resource;
   int id;
 
@@ -186,9 +212,12 @@ protected:
       selected = arrival->sim->get_resource(resource);
     else selected = arrival->get_resource_selected(id);
     if (!selected)
-      Rcpp::stop("%s: %s(%s, %i): no resource selected", arrival->name, name, resource, id);
+      Rcpp::stop("%s: %s(%s, %i): no resource selected", arrival->name, activity, resource, id);
     return selected;
   }
+
+private:
+  std::string activity;
 };
 
 /**
@@ -199,26 +228,26 @@ class Seize : public Fork, public ResGetter {
 public:
   CLONEABLE(Seize<T>)
 
-  Seize(const std::string& resource, const T& amount, int provide_attrs,
-        const VEC<bool>& cont, const VEC<Rcpp::Environment>& trj, unsigned short mask)
-    : Fork("Seize", cont, trj, VEC<int>(1, provide_attrs)),
+  Seize(const std::string& resource, const T& amount, const VEC<bool>& cont,
+        const VEC<REnv>& trj, unsigned short mask)
+    : Fork("Seize", cont, trj),
       ResGetter("Seize", resource), amount(amount), mask(mask) {}
 
-  Seize(int id, const T& amount, int provide_attrs,
-        const VEC<bool>& cont, const VEC<Rcpp::Environment>& trj, unsigned short mask)
-    : Fork("Seize", cont, trj, VEC<int>(1, provide_attrs)),
+  Seize(int id, const T& amount, const VEC<bool>& cont,
+        const VEC<REnv>& trj, unsigned short mask)
+    : Fork("Seize", cont, trj),
       ResGetter("Seize", "[]", id), amount(amount), mask(mask) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELC(resource) << LABELE(amount);
-    else Rcpp::Rcout << C(resource) << C(amount);
+    if (!brief) Rcpp::Rcout << LABEL2(resource, amount) << BENDL;
+    else Rcpp::Rcout << BARE2(resource, amount) << SEP;
     Fork::print(indent, verbose, brief);
   }
 
   double run(Arrival* arrival) {
-    int value = std::abs(get<int>(amount, 0, arrival));
-    return select_path(arrival, get_resource(arrival)->seize(arrival, value));
+    return select_path(
+      arrival, get_resource(arrival)->seize(arrival, std::abs(get<int>(amount, arrival))));
   }
 
 protected:
@@ -253,23 +282,22 @@ class Release : public Activity, public ResGetter {
 public:
   CLONEABLE(Release<T>)
 
-  Release(const std::string& resource, const T& amount, int provide_attrs)
-    : Activity("Release", VEC<int>(1, provide_attrs), PRIORITY_RELEASE),
+  Release(const std::string& resource, const T& amount)
+    : Activity("Release", PRIORITY_RELEASE),
       ResGetter("Release", resource), amount(amount) {}
 
-  Release(int id, const T& amount, int provide_attrs)
-    : Activity("Release", VEC<int>(1, provide_attrs), PRIORITY_RELEASE),
+  Release(int id, const T& amount)
+    : Activity("Release", PRIORITY_RELEASE),
       ResGetter("Release", "[]", id), amount(amount) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELC(resource) << LABELE(amount);
-    else Rcpp::Rcout << C(resource) << E(amount);
+    if (!brief) Rcpp::Rcout << LABEL2(resource, amount) << BENDL;
+    else Rcpp::Rcout << BARE2(resource, amount) << ENDL;
   }
 
   double run(Arrival* arrival) {
-    int value = std::abs(get<int>(amount, 0, arrival));
-    return get_resource(arrival)->release(arrival, value);
+    return get_resource(arrival)->release(arrival, std::abs(get<int>(amount, arrival)));
   }
 
 protected:
@@ -284,24 +312,29 @@ class SetCapacity : public Activity, public ResGetter {
 public:
   CLONEABLE(SetCapacity<T>)
 
-  SetCapacity(const std::string& resource, const T& value, int provide_attrs)
-    : Activity("SetCapacity", VEC<int>(1, provide_attrs)),
-      ResGetter("SetCapacity", resource), value(value) {}
+  SetCapacity(const std::string& resource, const T& value, char mod='N')
+    : Activity("SetCapacity"), ResGetter("SetCapacity", resource),
+      value(value), mod(mod), op(get_op<double>(mod)) {}
 
-  SetCapacity(int id, const T& value, int provide_attrs)
-    : Activity("SetCapacity", VEC<int>(1, provide_attrs)),
-      ResGetter("SetCapacity", "[]", id), value(value) {}
+  SetCapacity(int id, const T& value, char mod='N')
+    : Activity("SetCapacity"), ResGetter("SetCapacity", "[]", id),
+      value(value), mod(mod), op(get_op<double>(mod)) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELC(resource) << LABELE(value);
-    else Rcpp::Rcout << C(resource) << E(value);
+    if (!brief) Rcpp::Rcout << LABEL3(resource, value, mod) << BENDL;
+    else Rcpp::Rcout << BARE3(resource, value, mod) << ENDL;
   }
 
   double run(Arrival* arrival) {
-    double ret = std::abs(get<double>(value, 0, arrival));
-    if (ret == R_PosInf) ret = -1;
-    get_resource(arrival)->set_capacity((int)ret);
+    double ret = get<double>(value, arrival);
+    double oldval = get_resource(arrival)->get_capacity();
+    if (oldval < 0) oldval = R_PosInf;
+
+    if (op) ret = op(oldval, ret);
+    if (ret >= 0)
+      get_resource(arrival)->set_capacity((ret == R_PosInf) ? -1 : (int) ret);
+
     if (arrival->is_paused())
       return ENQUEUE;
     return 0;
@@ -309,6 +342,8 @@ public:
 
 protected:
   T value;
+  char mod;
+  Fn<double(double, double)> op;
 };
 
 /**
@@ -319,29 +354,36 @@ class SetQueue : public Activity, public ResGetter {
 public:
   CLONEABLE(SetQueue<T>)
 
-  SetQueue(const std::string& resource, const T& value, int provide_attrs)
-    : Activity("SetQueue", VEC<int>(1, provide_attrs)),
-      ResGetter("SetQueue", resource), value(value) {}
+  SetQueue(const std::string& resource, const T& value, char mod='N')
+    : Activity("SetQueue"), ResGetter("SetQueue", resource),
+      value(value), mod(mod), op(get_op<double>(mod)) {}
 
-  SetQueue(int id, const T& value, int provide_attrs)
-    : Activity("SetQueue", VEC<int>(1, provide_attrs)),
-      ResGetter("SetQueue", "[]", id), value(value) {}
+  SetQueue(int id, const T& value, char mod='N')
+    : Activity("SetQueue"), ResGetter("SetQueue", "[]", id),
+      value(value), mod(mod), op(get_op<double>(mod)) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELC(resource) << LABELE(value);
-    else Rcpp::Rcout << C(resource) << E(value);
+    if (!brief) Rcpp::Rcout << LABEL3(resource, value, mod) << BENDL;
+    else Rcpp::Rcout << BARE3(resource, value, mod) << ENDL;
   }
 
   double run(Arrival* arrival) {
-    double ret = std::abs(get<double>(value, 0, arrival));
-    if (ret == R_PosInf) ret = -1;
-    get_resource(arrival)->set_queue_size((int)ret);
+    double ret = get<double>(value, arrival);
+    double oldval = get_resource(arrival)->get_queue_size();
+    if (oldval < 0) oldval = R_PosInf;
+
+    if (op) ret = op(oldval, ret);
+    if (ret >= 0)
+      get_resource(arrival)->set_queue_size((ret == R_PosInf) ? -1 : (int) ret);
+
     return 0;
   }
 
 protected:
   T value;
+  char mod;
+  Fn<double(double, double)> op;
 };
 
 /**
@@ -352,19 +394,18 @@ class Select : public Activity {
 public:
   CLONEABLE(Select<T>)
 
-  Select(const T& resources, int provide_attrs, const std::string& policy, int id)
-    : Activity("Select", VEC<int>(1, provide_attrs)), resources(resources),
-      id(id), policy(Policy(policy)) {}
+  Select(const T& resources, const std::string& policy, int id)
+    : Activity("Select"), resources(resources), id(id), policy(Policy(policy)) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELC(resources) << LABELE(policy);
-    else Rcpp::Rcout << C(resources) << E(policy);
+    if (!brief) Rcpp::Rcout << LABEL2(resources, policy) << BENDL;
+    else Rcpp::Rcout << BARE2(resources, policy) << ENDL;
   }
 
   double run(Arrival* arrival) {
-    VEC<std::string> res = get<VEC<std::string> >(resources, 0, arrival);
-    arrival->set_resource_selected(id, policy.dispatch(arrival->sim, res));
+    arrival->set_resource_selected(
+        id, policy.dispatch(arrival->sim, get<VEC<std::string> >(resources, arrival)));
     return 0;
   }
 
@@ -382,28 +423,30 @@ class SetAttribute : public Activity {
 public:
   CLONEABLE(SetAttribute<T COMMA U>)
 
-  SetAttribute(const T& keys, const U& values, bool global, const VEC<int>& provide_attrs)
-    : Activity("SetAttribute", provide_attrs), keys(keys), values(values), global(global) {}
+  SetAttribute(const T& keys, const U& values, bool global, char mod='N')
+    : Activity("SetAttribute"), keys(keys), values(values),
+      global(global), mod(mod), op(get_op<double>(mod)) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELC(keys) << LABELC(values) << LABELE(global);
-    else Rcpp::Rcout << C(keys) << C(values) << E(global);
+    if (!brief) Rcpp::Rcout << LABEL4(keys, values, global, mod) << BENDL;
+    else Rcpp::Rcout << BARE4(keys, values, global, mod) << ENDL;
   }
 
   double run(Arrival* arrival) {
-    VEC<std::string> ks = get<VEC<std::string> >(keys, 0, arrival);
-    VEC<double> vals = get<VEC<double> >(values, 1, arrival);
+    VEC<std::string> ks = get<VEC<std::string> >(keys, arrival);
+    VEC<double> vals = get<VEC<double> >(values, arrival);
 
     if (ks.size() != vals.size())
       Rcpp::stop("%s: number of keys and values don't match", name);
 
-    boost::function<void (const std::string&, double)> setter;
-    if (global) setter = boost::bind(&Simulator::set_attribute, arrival->sim, _1, _2);
-    else setter = boost::bind(&Arrival::set_attribute, arrival, _1, _2);
-
-    for (unsigned int i = 0; i < ks.size(); i++)
-      setter(ks[i], vals[i]);
+    if (op) {
+      for (unsigned int i = 0; i < ks.size(); i++) {
+        double attr = arrival->get_attribute(ks[i], global);
+        arrival->set_attribute(ks[i], op(attr, vals[i]), global);
+      }
+    } else for (unsigned int i = 0; i < ks.size(); i++)
+      arrival->set_attribute(ks[i], vals[i], global);
 
     return 0;
   }
@@ -412,6 +455,8 @@ protected:
   T keys;
   U values;
   bool global;
+  char mod;
+  Fn<double(double, double)> op;
 };
 
 /**
@@ -422,19 +467,17 @@ class Activate : public Activity {
 public:
   CLONEABLE(Activate<T>)
 
-  Activate(const T& generator, int provide_attrs)
-    : Activity("Activate", VEC<int>(1, provide_attrs), PRIORITY_MAX),
-      generator(generator) {}
+  Activate(const T& generator)
+    : Activity("Activate"), generator(generator) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELE(generator);
-    else Rcpp::Rcout << E(generator);
+    if (!brief) Rcpp::Rcout << LABEL1(generator) << BENDL;
+    else Rcpp::Rcout << BARE1(generator) << ENDL;
   }
 
   double run(Arrival* arrival) {
-    std::string ret = get<std::string>(generator, 0, arrival);
-    arrival->sim->get_generator(ret)->activate();
+    arrival->sim->get_generator(get<std::string>(generator, arrival))->activate();
     return 0;
   }
 
@@ -450,19 +493,17 @@ class Deactivate : public Activity {
 public:
   CLONEABLE(Deactivate<T>)
 
-  Deactivate(const T& generator, int provide_attrs)
-    : Activity("Deactivate", VEC<int>(1, provide_attrs), PRIORITY_MAX),
-      generator(generator) {}
+  Deactivate(const T& generator)
+    : Activity("Deactivate"), generator(generator) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELE(generator);
-    else Rcpp::Rcout << E(generator);
+    if (!brief) Rcpp::Rcout << LABEL1(generator) << BENDL;
+    else Rcpp::Rcout << BARE1(generator) << ENDL;
   }
 
   double run(Arrival* arrival) {
-    std::string ret = get<std::string>(generator, 0, arrival);
-    arrival->sim->get_generator(ret)->deactivate();
+    arrival->sim->get_generator(get<std::string>(generator, arrival))->deactivate();
     return 0;
   }
 
@@ -478,25 +519,24 @@ class SetTraj : public Activity {
 public:
   CLONEABLE(SetTraj<T>)
 
-  SetTraj(const T& generator, int provide_attrs, const Rcpp::Environment& trajectory)
-    : Activity("SetTraj", VEC<int>(1, provide_attrs), PRIORITY_MAX),
-      generator(generator), trajectory(trajectory) {}
+  SetTraj(const T& generator, const REnv& trajectory)
+    : Activity("SetTraj"), generator(generator), trajectory(trajectory) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELC(generator) << LABELE(trajectory);
-    else Rcpp::Rcout << C(generator) << E(trajectory);
+    if (!brief) Rcpp::Rcout << LABEL2(generator, trajectory) << BENDL;
+    else Rcpp::Rcout << BARE2(generator, trajectory) << ENDL;
   }
 
   double run(Arrival* arrival) {
-    std::string ret = get<std::string>(generator, 0, arrival);
-    arrival->sim->get_generator(ret)->set_trajectory(trajectory);
+    arrival->sim->
+      get_generator(get<std::string>(generator, arrival))->set_trajectory(trajectory);
     return 0;
   }
 
 protected:
   T generator;
-  Rcpp::Environment trajectory;
+  REnv trajectory;
 };
 
 /**
@@ -507,25 +547,24 @@ class SetDist : public Activity {
 public:
   CLONEABLE(SetDist<T>)
 
-  SetDist(const T& generator, int provide_attrs, const Rcpp::Function& distribution)
-    : Activity("SetDist", VEC<int>(1, provide_attrs), PRIORITY_MAX),
-      generator(generator), distribution(distribution) {}
+  SetDist(const T& generator, const RFn& distribution)
+    : Activity("SetDist"), generator(generator), distribution(distribution) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELC(generator) << LABELE(distribution);
-    else Rcpp::Rcout << C(generator) << E(distribution);
+    if (!brief) Rcpp::Rcout << LABEL2(generator, distribution) << BENDL;
+    else Rcpp::Rcout << BARE2(generator, distribution) << ENDL;
   }
 
   double run(Arrival* arrival) {
-    std::string ret = get<std::string>(generator, 0, arrival);
-    arrival->sim->get_generator(ret)->set_distribution(distribution);
+    arrival->sim->
+      get_generator(get<std::string>(generator, arrival))->set_distribution(distribution);
     return 0;
   }
 
 protected:
   T generator;
-  Rcpp::Function distribution;
+  RFn distribution;
 };
 
 /**
@@ -536,27 +575,36 @@ class SetPrior : public Activity {
 public:
   CLONEABLE(SetPrior<T>)
 
-  SetPrior(const T& values, int provide_attrs)
-    : Activity("SetPrior", VEC<int>(1, provide_attrs)), values(values) {}
+  SetPrior(const T& values, char mod='N')
+    : Activity("SetPrior"), values(values), mod(mod), op(get_op<int>(mod)) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELE(values);
-    else Rcpp::Rcout << E(values);
+    if (!brief) Rcpp::Rcout << LABEL2(values, mod) << BENDL;
+    else Rcpp::Rcout << BARE2(values, mod) << ENDL;
   }
 
   double run(Arrival* arrival) {
-    VEC<int> ret = get<VEC<int> >(values, 0, arrival);
+    VEC<int> ret = get<VEC<int> >(values, arrival);
     if (ret.size() != 3)
       Rcpp::stop("%s: 3 values needed", name);
+
+    if (op) {
+      ret[0] = op(arrival->order.get_priority(), ret[0]);
+      ret[1] = op(arrival->order.get_preemptible(), ret[1]);
+      ret[2] = op((int)arrival->order.get_restart(), ret[2]);
+    }
     if (ret[0] >= 0) arrival->order.set_priority(ret[0]);
     if (ret[1] >= 0) arrival->order.set_preemptible(ret[1]);
     if (ret[2] >= 0) arrival->order.set_restart((bool)ret[2]);
+
     return 0;
   }
 
 protected:
   T values;
+  char mod;
+  Fn<int(int, int)> op;
 };
 
 /**
@@ -567,17 +615,16 @@ class Timeout : public Activity {
 public:
   CLONEABLE(Timeout<T>)
 
-  Timeout(const T& delay, int provide_attrs)
-    : Activity("Timeout", VEC<int>(1, provide_attrs)), delay(delay) {}
+  Timeout(const T& delay) : Activity("Timeout"), delay(delay) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELE(delay);
-    else Rcpp::Rcout << E(delay);
+    if (!brief) Rcpp::Rcout << LABEL1(delay) << BENDL;
+    else Rcpp::Rcout << BARE1(delay) << ENDL;
   }
 
   double run(Arrival* arrival) {
-    double value = get<double>(delay, 0, arrival);
+    double value = get<double>(delay, arrival);
     if (ISNAN(value))
       Rcpp::stop("%s: missing value (NA or NaN returned)", name);
     return std::abs(value);
@@ -595,19 +642,18 @@ class Branch : public Fork {
 public:
   CLONEABLE(Branch)
 
-  Branch(const Rcpp::Function& option, int provide_attrs,
-         const VEC<bool>& cont, const VEC<Rcpp::Environment>& trj)
-    : Fork("Branch", cont, trj, VEC<int>(1, provide_attrs)), option(option) {}
+  Branch(const RFn& option, const VEC<bool>& cont, const VEC<REnv>& trj)
+    : Fork("Branch", cont, trj), option(option) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELE(option);
-    else Rcpp::Rcout << C(option);
+    if (!brief) Rcpp::Rcout << LABEL1(option) << BENDL;
+    else Rcpp::Rcout << BARE1(option) << SEP;
     Fork::print(indent, verbose, brief);
   }
 
   double run(Arrival* arrival) {
-    int ret = get<int>(option, 0, arrival);
+    int ret = get<int>(option, arrival);
     if (ret < 0 || ret > (int)heads.size())
       Rcpp::stop("%s: index out of range", name);
     if (ret) selected = heads[ret-1];
@@ -615,7 +661,7 @@ public:
   }
 
 protected:
-  Rcpp::Function option;
+  RFn option;
 };
 
 /**
@@ -625,31 +671,27 @@ class Rollback : public Activity {
 public:
   CLONEABLE(Rollback)
 
-  Rollback(int amount, int times,
-           const OPT<Rcpp::Function>& check = NONE, int provide_attrs = false)
-    : Activity("Rollback", VEC<int>(1, provide_attrs)), amount(std::abs(amount)),
+  Rollback(int amount, int times, const OPT<RFn>& check = NONE)
+    : Activity("Rollback"), amount(std::abs(amount)),
       times(times), check(check), cached(NULL), selected(NULL) {}
 
   Rollback(const Rollback& o)
     : Activity(o), amount(o.amount), times(o.times), check(o.check),
-      cached(NULL), selected(NULL)
-  {
-    pending.clear();
-  }
+      cached(NULL), selected(NULL) { pending.clear(); }
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     if (!cached) cached = goback();
     Activity::print(indent, verbose, brief);
     if (!brief) {
-      Rcpp::Rcout << "amount: " << amount << " (" << cached->name << "), ";
-      if (check) Rcpp::Rcout << LABELE(*check);
-      else Rcpp::Rcout << LABELE(times);
-    } else Rcpp::Rcout << cached->name << std::endl;
+      Rcpp::Rcout << LABEL1(amount) << " (" << cached->name << "), ";
+      if (check) Rcpp::Rcout << LABEL1(*check) << BENDL;
+      else Rcpp::Rcout << LABEL1(times) << BENDL;
+    } else Rcpp::Rcout << BARE1(cached->name) << ENDL;
   }
 
   double run(Arrival* arrival) {
     if (check) {
-      if (!get<bool>(*check, 0, arrival))
+      if (!get<bool>(*check, arrival))
         return 0;
     } else if (times >= 0) {
       if (pending.find(arrival) == pending.end())
@@ -677,7 +719,7 @@ public:
 protected:
   int amount;
   int times;
-  OPT<Rcpp::Function> check;
+  OPT<RFn> check;
   Activity* cached, *selected;
   UMAP<Arrival*, int> pending;
 
@@ -698,17 +740,16 @@ class Leave : public Activity {
 public:
   CLONEABLE(Leave<T>)
 
-  Leave(const T& prob, int provide_attrs)
-    : Activity("Leave", VEC<int>(1, provide_attrs)), prob(prob) {}
+  Leave(const T& prob) : Activity("Leave"), prob(prob) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELE(prob);
-    else Rcpp::Rcout << E(prob);
+    if (!brief) Rcpp::Rcout << LABEL1(prob) << BENDL;
+    else Rcpp::Rcout << BARE1(prob) << ENDL;
   }
 
   double run(Arrival* arrival) {
-    if (Rcpp::runif(1)[0] > get<double>(prob, 0, arrival))
+    if (Rcpp::runif(1)[0] > get<double>(prob, arrival))
       return 0;
     arrival->terminate(false);
     return REJECT;
@@ -726,20 +767,19 @@ class Clone : public Fork {
 public:
   CLONEABLE(Clone<T>)
 
-  Clone(const T& n, int provide_attrs, const VEC<Rcpp::Environment>& trj)
-    : Fork("Clone", VEC<bool>(trj.size(), true),
-      trj, VEC<int>(1, provide_attrs)), n(n) {}
+  Clone(const T& n, const VEC<REnv>& trj)
+    : Fork("Clone", VEC<bool>(trj.size(), true), trj), n(n) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELE(n);
-    else Rcpp::Rcout << C(n);
+    if (!brief) Rcpp::Rcout << LABEL1(n) << BENDL;
+    else Rcpp::Rcout << BARE1(n) << SEP;
     Fork::print(indent, verbose, brief);
   }
 
   double run(Arrival* arrival) {
-    unsigned int value = std::abs(get<int>(n, 0, arrival));
-    for (unsigned int i = 1; i < value; i++) {
+    unsigned int ret = (unsigned int) std::abs(get<int>(n, arrival));
+    for (unsigned int i = 1; i < ret; i++) {
       if (i < heads.size())
         selected = heads[i];
       Arrival* new_arrival = arrival->clone();
@@ -766,15 +806,12 @@ public:
     : Activity("Synchronize"), wait(wait), terminate(terminate) {}
 
   Synchronize(const Synchronize& o)
-    : Activity(o), wait(o.wait), terminate(o.terminate)
-  {
-    pending.clear();
-  }
+    : Activity(o), wait(o.wait), terminate(o.terminate) { pending.clear(); }
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELE(wait);
-    else Rcpp::Rcout << E(wait);
+    if (!brief) Rcpp::Rcout << LABEL1(wait) << BENDL;
+    else Rcpp::Rcout << BARE1(wait) << ENDL;
   }
 
   double run(Arrival* arrival) {
@@ -813,20 +850,20 @@ class Batch : public Activity {
 public:
   CLONEABLE(Batch<T>)
 
-  Batch(int n, const T& timeout, const VEC<int>& provide_attrs, bool permanent,
-        const std::string& id = "", const OPT<Rcpp::Function>& rule = NONE)
-    : Activity("Batch", provide_attrs),
+  Batch(int n, const T& timeout, bool permanent,
+        const std::string& id = "", const OPT<RFn>& rule = NONE)
+    : Activity("Batch"),
       n(n), timeout(timeout), permanent(permanent), id(id), rule(rule) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
     if (!brief)
-      Rcpp::Rcout << LABELC(n) << LABELC(timeout) << LABELC(permanent) << LABELE(id);
-    else Rcpp::Rcout << C(n) << C(timeout) << C(permanent) << E(id);
+      Rcpp::Rcout << LABEL4(n, timeout, permanent, id) << BENDL;
+    else Rcpp::Rcout << BARE4(n, timeout, permanent, id) << ENDL;
   }
 
   double run(Arrival* arrival) {
-    if (rule && !get<bool>(*rule, 1, arrival))
+    if (rule && !get<bool>(*rule, arrival))
       return 0;
     Batched** ptr = arrival->sim->get_batch(this, id);
     if (!(*ptr))
@@ -842,7 +879,7 @@ protected:
   T timeout;
   bool permanent;
   std::string id;
-  OPT<Rcpp::Function> rule;
+  OPT<RFn> rule;
 
   Batched* init(Arrival* arrival) {
     std::string str;
@@ -855,10 +892,10 @@ protected:
       str= "batch" + boost::lexical_cast<std::string>(count);
       ptr = new Batched(arrival->sim, str, permanent, count);
     }
-    double dt = std::abs(get<double>(timeout, 0, arrival));
+    double dt = std::abs(get<double>(timeout, arrival));
     if (dt) {
       Task* task = new Task(arrival->sim, "Batch-Timer",
-                            boost::bind(&Batch::trigger, this, arrival->sim, ptr),
+                            BIND(&Batch::trigger, this, arrival->sim, ptr),
                             PRIORITY_MIN);
       task->activate(dt);
     }
@@ -891,8 +928,8 @@ public:
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << " }" << std::endl;
-    else Rcpp::Rcout << std::endl;
+    if (!brief) Rcpp::Rcout << BENDL;
+    else Rcpp::Rcout << ENDL;
   }
 
   double run(Arrival* arrival) {
@@ -913,23 +950,21 @@ class RenegeIn : public Fork {
 public:
   CLONEABLE(RenegeIn<T>)
 
-  RenegeIn(const T& t, int provide_attrs, const VEC<Rcpp::Environment>& trj)
-    : Fork("RenegeIn", VEC<bool>(trj.size(), false),
-      trj, VEC<int>(1, provide_attrs)), t(t) {}
+  RenegeIn(const T& t, const VEC<REnv>& trj)
+    : Fork("RenegeIn", VEC<bool>(trj.size(), false), trj), t(t) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELE(t);
-    else Rcpp::Rcout << C(t);
+    if (!brief) Rcpp::Rcout << LABEL1(t) << BENDL;
+    else Rcpp::Rcout << BARE1(t) << SEP;
     Fork::print(indent, verbose, brief);
   }
 
   double run(Arrival* arrival) {
-    double ret = std::abs(get<double>(t, 0, arrival));
     Activity* next = NULL;
     if (heads.size())
       next = heads[0];
-    arrival->set_renege(ret, next);
+    arrival->set_renege(std::abs(get<double>(t, arrival)), next);
     return 0;
   }
 
@@ -945,23 +980,21 @@ class RenegeIf : public Fork {
 public:
   CLONEABLE(RenegeIf<T>)
 
-  RenegeIf(const T& signal, int provide_attrs, const VEC<Rcpp::Environment>& trj)
-    : Fork("RenegeIf", VEC<bool>(trj.size(), false),
-      trj, VEC<int>(1, provide_attrs)), signal(signal) {}
+  RenegeIf(const T& signal, const VEC<REnv>& trj)
+    : Fork("RenegeIf", VEC<bool>(trj.size(), false), trj), signal(signal) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELE(signal);
-    else Rcpp::Rcout << C(signal);
+    if (!brief) Rcpp::Rcout << LABEL1(signal) << BENDL;
+    else Rcpp::Rcout << BARE1(signal) << SEP;
     Fork::print(indent, verbose, brief);
   }
 
   double run(Arrival* arrival) {
-    std::string ret = get<std::string>(signal, 0, arrival);
     Activity* next = NULL;
     if (heads.size())
       next = heads[0];
-    arrival->set_renege(ret, next);
+    arrival->set_renege(get<std::string>(signal, arrival), next);
     return 0;
   }
 
@@ -980,8 +1013,8 @@ public:
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << " }" << std::endl;
-    else Rcpp::Rcout << std::endl;
+    if (!brief) Rcpp::Rcout << BENDL;
+    else Rcpp::Rcout << ENDL;
   }
 
   double run(Arrival* arrival) {
@@ -998,23 +1031,23 @@ class Send : public Activity {
 public:
   CLONEABLE(Send<T COMMA U>)
 
-  Send(const T& signals, const U& delay, const VEC<int>& provide_attrs)
-    : Activity("Send", provide_attrs), signals(signals), delay(delay) {}
+  Send(const T& signals, const U& delay)
+    : Activity("Send", PRIORITY_SEND), signals(signals), delay(delay) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELC(signals) << LABELE(delay);
-    else Rcpp::Rcout << C(signals) << E(delay);
+    if (!brief) Rcpp::Rcout << LABEL2(signals, delay) << BENDL;
+    else Rcpp::Rcout << BARE2(signals, delay) << ENDL;
   }
 
   double run(Arrival* arrival) {
-    VEC<std::string> sigs = get<VEC<std::string> >(signals, 0, arrival);
-    double t = std::abs(get<double>(delay, 1, arrival));
+    double lag = std::abs(get<double>(delay, arrival));
     Task* task =
       new Task(arrival->sim, "Broadcast",
-               boost::bind(&Simulator::broadcast, arrival->sim, sigs),
-               PRIORITY_MIN);
-    task->activate(t);
+               BIND(&Simulator::broadcast, arrival->sim,
+                    get<VEC<std::string> >(signals, arrival)),
+               lag ? PRIORITY_MIN : PRIORITY_SIGNAL);
+    task->activate(lag);
     return 0;
   }
 
@@ -1031,10 +1064,8 @@ class Trap : public Fork {
 public:
   CLONEABLE(Trap<T>)
 
-  Trap(const T& signals, int provide_attrs,
-       const VEC<Rcpp::Environment>& trj, bool interruptible)
-    : Fork("Trap", VEC<bool>(trj.size(), false),
-      trj, VEC<int>(1, provide_attrs)),
+  Trap(const T& signals, const VEC<REnv>& trj, bool interruptible)
+    : Fork("Trap", VEC<bool>(trj.size(), false), trj, PRIORITY_TRAP),
       signals(signals), interruptible(interruptible) {}
 
   Trap(const Trap& o) : Fork(o), signals(o.signals), interruptible(o.interruptible) {
@@ -1043,8 +1074,8 @@ public:
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELE(signals);
-    else Rcpp::Rcout << C(signals);
+    if (!brief) Rcpp::Rcout << LABEL1(signals) << BENDL;
+    else Rcpp::Rcout << BARE1(signals) << SEP;
     Fork::print(indent, verbose, brief);
   }
 
@@ -1056,9 +1087,8 @@ public:
       arrival->activate();
       return REJECT;
     }
-    VEC<std::string> sigs = get<VEC<std::string> >(signals, 0, arrival);
-    arrival->sim->subscribe(sigs, arrival,
-                            boost::bind(&Trap::launch_handler, this, arrival));
+    arrival->sim->subscribe(get<VEC<std::string> >(signals, arrival), arrival,
+                            BIND(&Trap::launch_handler, this, arrival));
     return 0;
   }
 
@@ -1093,18 +1123,16 @@ class UnTrap : public Activity {
 public:
   CLONEABLE(UnTrap<T>)
 
-  UnTrap(const T& signals, int provide_attrs)
-    : Activity("UnTrap", VEC<int>(1, provide_attrs)), signals(signals) {}
+  UnTrap(const T& signals) : Activity("UnTrap", PRIORITY_TRAP), signals(signals) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << LABELE(signals);
-    else Rcpp::Rcout << E(signals);
+    if (!brief) Rcpp::Rcout << LABEL1(signals) << BENDL;
+    else Rcpp::Rcout << BARE1(signals) << ENDL;
   }
 
   double run(Arrival* arrival) {
-    VEC<std::string> sigs = get<VEC<std::string> >(signals, 0, arrival);
-    arrival->sim->unsubscribe(sigs, arrival);
+    arrival->sim->unsubscribe(get<VEC<std::string> >(signals, arrival), arrival);
     return 0;
   }
 
@@ -1123,8 +1151,8 @@ public:
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << " }" << std::endl;
-    else Rcpp::Rcout << std::endl;
+    if (!brief) Rcpp::Rcout << BENDL;
+    else Rcpp::Rcout << ENDL;
   }
 
   double run(Arrival* arrival) { return BLOCK; }
@@ -1138,18 +1166,17 @@ class Log : public Activity {
 public:
   CLONEABLE(Log<T>)
 
-  Log(const T& message, int provide_attrs)
-    : Activity("Log", VEC<int>(1, provide_attrs)), message(message) {}
+  Log(const T& message) : Activity("Log"), message(message) {}
 
   void print(unsigned int indent = 0, bool verbose = false, bool brief = false) {
     Activity::print(indent, verbose, brief);
-    if (!brief) Rcpp::Rcout << "message }" << std::endl;
-    else Rcpp::Rcout << "message" << std::endl;
+    if (!brief) Rcpp::Rcout << "message" << BENDL;
+    else Rcpp::Rcout << "message" << ENDL;
   }
 
   double run(Arrival* arrival) {
     Rcpp::Rcout << arrival->sim->now() << ": " << arrival->name << ": " <<
-      get<std::string>(message, 0, arrival) << std::endl;
+      get<std::string>(message, arrival) << std::endl;
     return 0;
   }
 
