@@ -155,10 +155,10 @@ public:
   }
 
 protected:
-  RPQueue queue;
-  QueueMap queue_map;
   T server;
   ServerMap server_map;
+  RPQueue queue;
+  QueueMap queue_map;
 
   bool first_in_line(int priority) const {
     if (queue.empty() || queue.begin()->priority() < priority)
@@ -173,7 +173,7 @@ protected:
   bool room_in_queue(int amount, int priority) const {
     if (queue_size < 0 || queue_count + amount <= queue_size)
       return true;
-    int count = (this->queue_size > 0) ? (this->queue_size - this->queue_count) : 0;
+    int count = (queue_size > 0) ? (queue_size - queue_count) : 0;
     foreach_r_ (const RPQueue::value_type& itr, queue) {
       if (priority > itr.priority())
         count += itr.amount;
@@ -290,6 +290,18 @@ public:
   }
 
 protected:
+  using Resource::capacity;
+  using Resource::server_count;
+  using Resource::queue_count;
+  using Resource::queue_size_strict;
+  using Resource::verbose_print;
+
+  using PriorityRes<T>::server;
+  using PriorityRes<T>::server_map;
+  using PriorityRes<T>::room_in_queue;
+  using PriorityRes<T>::insert_in_server;
+  using PriorityRes<T>::insert_in_queue;
+
   RPQueue preempted;
   QueueMap preempted_map;
 
@@ -302,8 +314,8 @@ protected:
   bool room_in_server(int amount, int priority) const {
     if (PriorityRes<T>::room_in_server(amount, priority))
       return true;
-    int count = (this->capacity > 0) ? (this->capacity - this->server_count) : 0;
-    foreach_ (const typename T::value_type& itr, this->server) {
+    int count = (capacity > 0) ? (capacity - server_count) : 0;
+    foreach_ (const typename T::value_type& itr, server) {
       if (priority > itr.preemptible())
         count += itr.amount;
       else
@@ -316,25 +328,25 @@ protected:
 
   int try_free_server(bool verbose, double time) {
     int count = 0;
-    typename T::iterator first = this->server.begin();
-    if (first == this->server.end())
+    typename T::iterator first = server.begin();
+    if (first == server.end())
       return count;
     first->arrival->pause();
-    if (verbose) this->verbose_print(time, first->arrival->name, "PREEMPT");
+    if (verbose) verbose_print(time, first->arrival->name, "PREEMPT");
     count += first->amount;
-    this->server_count -= first->amount;
-    this->server_map.erase(first->arrival);
-    if (this->queue_size_strict) {
-      if (!this->room_in_queue(first->amount, first->priority())) {
-        if (verbose) this->verbose_print(time, first->arrival->name, "REJECT");
+    server_count -= first->amount;
+    server_map.erase(first->arrival);
+    if (queue_size_strict) {
+      if (!room_in_queue(first->amount, first->priority())) {
+        if (verbose) verbose_print(time, first->arrival->name, "REJECT");
         first->arrival->unregister_entity(this);
         first->arrival->terminate(false);
-      } else this->insert_in_queue(verbose, time, first->arrival, first->amount);
+      } else insert_in_queue(verbose, time, first->arrival, first->amount);
     } else {
       preempted_map[first->arrival] = preempted.insert(*first);
-      this->queue_count += first->amount;
+      queue_count += first->amount;
     }
-    this->server.erase(first);
+    server.erase(first);
     return count;
   }
 
@@ -346,9 +358,9 @@ protected:
     if (!room_in_server(next->amount, next->priority()))
       return count;
     next->arrival->restart();
-    this->insert_in_server(verbose, time, next->arrival, next->amount);
+    insert_in_server(verbose, time, next->arrival, next->amount);
     count += next->amount;
-    this->queue_count -= next->amount;
+    queue_count -= next->amount;
     preempted_map.erase(next->arrival);
     preempted.erase(next);
     return count;
@@ -359,9 +371,9 @@ protected:
     QueueMap::iterator search = preempted_map.find(arrival);
     if (count || search == preempted_map.end())
       return count;
-    if (verbose) this->verbose_print(time, arrival->name, "DEPART");
+    if (verbose) verbose_print(time, arrival->name, "DEPART");
     count += search->second->amount;
-    this->queue_count -= search->second->amount;
+    queue_count -= search->second->amount;
     search->second->arrival->unregister_entity(this);
     preempted.erase(search->second);
     preempted_map.erase(search);
