@@ -1,5 +1,10 @@
 context("timeout")
 
+test_that("incorrect types fail", {
+  expect_error(trajectory() %>% timeout("dummy"))
+  expect_error(trajectory() %>% timeout_from_attribute(2))
+})
+
 test_that("a task function that returns a non-numeric value fails", {
   t0 <- trajectory() %>%
     timeout(function() {})
@@ -7,25 +12,35 @@ test_that("a task function that returns a non-numeric value fails", {
   env <- simmer(verbose = TRUE) %>%
     add_generator("entity", t0, function() 1)
 
-  expect_error(env %>% run(100))
+  expect_error(run(env))
 })
 
 test_that("a missing value fails", {
-  expect_error(trajectory() %>% timeout(NA))
-
   t0 <- trajectory() %>%
     timeout(NaN)
-  env <- simmer(verbose = TRUE) %>%
+  t1 <- trajectory() %>%
+    timeout_from_attribute("asdf")
+
+  env0 <- simmer(verbose = TRUE) %>%
     add_generator("dummy", t0, at(0))
-  expect_error(env %>% run())
+  env1 <- simmer(verbose = TRUE) %>%
+    add_generator("dummy", t1, at(0))
+
+  expect_error(trajectory() %>% timeout(NA))
+  expect_error(run(env0))
+  expect_error(run(env1))
 })
 
 test_that("a timeout is correctly monitored", {
   t <- trajectory() %>%
+    set_attribute("three", 3) %>%
+    set_global("minusthree", -3) %>%
     seize("dummy") %>%
     timeout(-3) %>%
     timeout(3) %>%
     timeout(function() 4) %>%
+    timeout_from_attribute("three") %>%
+    timeout_from_global("minusthree") %>%
     release("dummy")
 
   env <- simmer(verbose = TRUE) %>%
@@ -33,10 +48,6 @@ test_that("a timeout is correctly monitored", {
     add_resource("dummy") %>%
     run()
 
-  expect_equal(get_mon_arrivals(env)[1, ]$end_time, 10)
-  expect_equal(get_mon_arrivals(env, TRUE)[1, ]$end_time, 10)
-})
-
-test_that("incorrect types fail", {
-  expect_error(trajectory() %>% timeout("dummy"))
+  expect_equal(get_mon_arrivals(env)[1, ]$end_time, 16)
+  expect_equal(get_mon_arrivals(env, TRUE)[1, ]$end_time, 16)
 })
